nbxmpp.auth_nb.NonBlockingNonSASL

Package nbxmpp :: Module auth_nb :: Class NonBlockingNonSASL |
[hide private]
[frames] | no frames]

# Class NonBlockingNonSASL

source code

Implements old Non-SASL (JEP-0078) authentication used in jabberd1.4 and transport authentication

Instance Methods | [hide private]
__init__(self, user, password, resource, on_auth) Caches username, password and resource for auth | source code
plugin(self, owner) Determine the best auth method (digest/0k/plain) and use it for auth. Returns used method name on success. Used internally | source code
_on_username(self, resp) | source code
_on_password(self, password) | source code
_on_auth(self, resp) | source code
Inherited from `plugin.PlugIn`: `PlugIn`, `PlugOut`

Class Methods | [hide private]
Inherited from `plugin.PlugIn`: `get_instance`

Method Details | [hide private]

### __init__(self, user, password, resource, on_auth) (Constructor) | source code
Caches username, password and resource for auth Overrides: plugin.PlugIn.__init__

### plugin(self, owner) | source code
Determine the best auth method (digest/0k/plain) and use it for auth. Returns used method name on success. Used internally

### _on_username(self, resp) | source code

### _on_password(self, password) | source code

### _on_auth(self, resp) | source code